==> kubernetes-model-node-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/RuntimeClassSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RuntimeClassSpecBuilder extends io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluentImpl<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecBuilder>{
  public RuntimeClassSpecBuilder() {
    this(false);
  }
  public RuntimeClassSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new RuntimeClassSpec(), validationEnabled);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RuntimeClassSpec(), validationEnabled);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance) {
    this(fluent, instance, false);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withOverhead(instance.getOverhead()); 
    fluent.withRuntimeHandler(instance.getRuntimeHandler()); 
    fluent.withScheduling(instance.getScheduling()); 
    this.validationEnabled = validationEnabled; 
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance) {
    this(instance,false);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withOverhead(instance.getOverhead()); 
    this.withRuntimeHandler(instance.getRuntimeHandler()); 
    this.withScheduling(instance.getScheduling()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec build() {
    RuntimeClassSpec buildable = new RuntimeClassSpec(fluent.getOverhead(),fluent.getRuntimeHandler(),fluent.getScheduling());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RuntimeClassSpecBuilder that = (RuntimeClassSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-node-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/node/v1alpha1/RuntimeClassSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RuntimeClassSpecBuilder extends io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluentImpl<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecBuilder>{
  public RuntimeClassSpecBuilder() {
    this(false);
  }
  public RuntimeClassSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new RuntimeClassSpec(), validationEnabled);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RuntimeClassSpec(), validationEnabled);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance) {
    this(fluent, instance, false);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withOverhead(instance.getOverhead()); 
    fluent.withRuntimeHandler(instance.getRuntimeHandler()); 
    fluent.withScheduling(instance.getScheduling()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance) {
    this(instance,false);
  }
  public RuntimeClassSpecBuilder(io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withOverhead(instance.getOverhead()); 
    this.withRuntimeHandler(instance.getRuntimeHandler()); 
    this.withScheduling(instance.getScheduling()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.node.v1alpha1.RuntimeClassSpec build() {
    RuntimeClassSpec buildable = new RuntimeClassSpec(fluent.getOverhead(),fluent.getRuntimeHandler(),fluent.getScheduling());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RuntimeClassSpecBuilder that = (RuntimeClassSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
